diff -uNr fltk-1.1.6/FL/Fl_Window.H fltk-1.1.6-ce/FL/Fl_Window.H
--- fltk-1.1.6/FL/Fl_Window.H	2004-11-20 01:19:57.000000000 -0200
+++ fltk-1.1.6-ce/FL/Fl_Window.H	2006-01-24 16:10:08.000000000 -0200
@@ -58,11 +58,23 @@
   };
   void _Fl_Window(); // constructor innards
 
-protected:
+public:
+  // values for set_hint():
+  enum {
+    FL_WINDOW_TYPE_HINT_NONE,
+    FL_WINDOW_TYPE_HINT_TOOLBAR,
+    FL_WINDOW_TYPE_HINT_DOCK,
+    FL_WINDOW_TYPE_HINT_DIALOG,
+    FL_WINDOW_TYPE_HINT_SPLASH,
+    FL_WINDOW_TYPE_HINT_DESKTOP
+  };
 
+protected:
+  int _hint;
   static Fl_Window *current_;
   virtual void draw();
   virtual void flush();
+  void hint(Fl_X*);
 
 public:
 
@@ -72,6 +84,8 @@
 
   virtual int handle(int);
 
+  void set_hint(int hint) { _hint = hint; };
+
   virtual void resize(int,int,int,int);
   void border(int b);
   void clear_border()	{set_flag(FL_NOBORDER);}
diff -uNr fltk-1.1.6/src/fl_ask.cxx fltk-1.1.6-ce/src/fl_ask.cxx
--- fltk-1.1.6/src/fl_ask.cxx	2004-10-18 17:22:25.000000000 -0300
+++ fltk-1.1.6-ce/src/fl_ask.cxx	2006-01-24 15:33:24.000000000 -0200
@@ -60,6 +60,7 @@
    return message_form;
  }
  Fl_Window *w = message_form = new Fl_Window(410,103,"");
+ w->set_hint (Fl_Window::FL_WINDOW_TYPE_HINT_DIALOG);
  // w->clear_border();
  // w->box(FL_UP_BOX);
  (message = new Fl_Box(60, 25, 340, 20))
diff -uNr fltk-1.1.6/src/Fl_Window.cxx fltk-1.1.6-ce/src/Fl_Window.cxx
--- fltk-1.1.6/src/Fl_Window.cxx	2004-04-11 01:38:58.000000000 -0300
+++ fltk-1.1.6-ce/src/Fl_Window.cxx	2006-01-24 14:13:02.000000000 -0200
@@ -57,6 +57,8 @@
   cursor_fg      = FL_BLACK;
   cursor_bg      = FL_WHITE;
 
+  _hint = FL_WINDOW_TYPE_HINT_NONE;
+
   _Fl_Window();
   set_flag(FL_FORCE_POSITION);
 }
@@ -68,6 +70,8 @@
   cursor_fg      = FL_BLACK;
   cursor_bg      = FL_WHITE;
 
+  _hint = FL_WINDOW_TYPE_HINT_NONE;
+
   _Fl_Window();
   clear_visible();
 }
diff -uNr fltk-1.1.6/src/Fl_x.cxx fltk-1.1.6-ce/src/Fl_x.cxx
--- fltk-1.1.6/src/Fl_x.cxx	2004-11-20 11:52:47.000000000 -0200
+++ fltk-1.1.6-ce/src/Fl_x.cxx	2006-01-24 16:15:35.000000000 -0200
@@ -284,7 +284,12 @@
 Atom fl_XdndActionCopy;
 Atom fl_XdndFinished;
 //Atom fl_XdndProxy;
-
+Atom fl_WINDOW_TYPE;
+Atom fl_HINT_TOOLBAR;
+Atom fl_HINT_DOCK;
+Atom fl_HINT_DIALOG;
+Atom fl_HINT_SPLASH;
+Atom fl_HINT_DESKTOP;
 
 static void fd_callback(int,void *) {
   do_queued_events();
@@ -337,6 +342,12 @@
   fl_XdndActionCopy     = XInternAtom(d, "XdndActionCopy",	0);
   fl_XdndFinished       = XInternAtom(d, "XdndFinished",	0);
   //fl_XdndProxy        = XInternAtom(d, "XdndProxy",		0);
+  fl_WINDOW_TYPE        = XInternAtom(d, "_NET_WM_WINDOW_TYPE",         0);
+  fl_HINT_TOOLBAR       = XInternAtom(d, "_NET_WM_WINDOW_TYPE_TOOLBAR", 0);
+  fl_HINT_DOCK          = XInternAtom(d, "_NET_WM_WINDOW_TYPE_DOCK",    0);
+  fl_HINT_DIALOG        = XInternAtom(d, "_NET_WM_WINDOW_TYPE_DIALOG",  0);
+  fl_HINT_SPLASH        = XInternAtom(d, "_NET_WM_WINDOW_TYPE_SPLASH",  0);
+  fl_HINT_DESKTOP       = XInternAtom(d, "_NET_WM_WINDOW_TYPE_DESKTOP", 0);
 
   Fl::add_fd(ConnectionNumber(d), POLLIN, fd_callback);
 
@@ -936,6 +947,27 @@
 
 ////////////////////////////////////////////////////////////////
 
+void Fl_Window::hint(Fl_X* xp) {
+  Atom *atom;
+
+  switch (_hint) {
+  case FL_WINDOW_TYPE_HINT_TOOLBAR:
+    atom = &fl_HINT_TOOLBAR; break;
+  case FL_WINDOW_TYPE_HINT_DOCK:
+    atom = &fl_HINT_DOCK; break;
+  case FL_WINDOW_TYPE_HINT_DIALOG:
+    atom = &fl_HINT_DIALOG; break;
+  case FL_WINDOW_TYPE_HINT_SPLASH:
+    atom = &fl_HINT_SPLASH; break;
+  case FL_WINDOW_TYPE_HINT_DESKTOP:
+    atom = &fl_HINT_DESKTOP; break;
+  default: return;
+  }
+
+  XChangeProperty(fl_display, xp->xid, fl_WINDOW_TYPE, XA_ATOM,
+                  32, PropModeReplace, (unsigned char*) atom, 1);
+}
+
 void Fl_Window::resize(int X,int Y,int W,int H) {
   int is_a_move = (X != x() || Y != y());
   int is_a_resize = (W != w() || H != h());
@@ -1137,6 +1169,9 @@
     XFree(hints);
   }
 
+  // hint
+  win->hint(xp);
+
   XMapWindow(fl_display, xp->xid);
   if (showit) {
     win->set_visible();
